##
##  consul-replicate.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2020 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_consul_replicate_base 0.4.0
%define       V_consul_replicate_snap 20200125

#   package information
Name:         consul-replicate
Summary:      Cross-Datacenter Replication Service for Consul
URL:          https://github.com/hashicorp/consul-replicate
Vendor:       Hashicorp
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      MPL
Version:      %{V_consul_replicate_base}.%{V_consul_replicate_snap}
Release:      20200125

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/consul/consul-replicate-%{V_consul_replicate_snap}.tar.xz
Source1:      rc.consul-replicate
Source2:      consul-replicate.conf

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go
PreReq:       OpenPKG, openpkg >= 20160101, consul

%description
    This is a companion tool to Consul, a service discovery and
    configuration service. It provides a convenient way to replicate K/V
    pairs across multiple Consul datacenters.

%track
    prog consul-replicate:release = {
        version   = %{V_consul_replicate_base}
        url       = https://github.com/hashicorp/consul-replicate/releases
        regex     = v(__VER__)\.tar\.gz
    }
    prog consul-replicate:snapshot = {
        version   = %{V_consul_replicate_snap}
        url       = http://download.openpkg.org/components/versioned/consul/
        regex     = consul-replicate-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n consul-replicate

%build
    #   build program
    export GOPATH=`pwd`
    cd src/github.com/hashicorp/consul-replicate
    go build -v -o bin/consul-replicate

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/consul-replicate \
        $RPM_BUILD_ROOT%{l_prefix}/var/consul-replicate/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/consul-replicate/run

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/hashicorp/consul-replicate/bin/consul-replicate \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/consul-replicate

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.consul-replicate} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE consul-replicate.conf} $RPM_BUILD_ROOT%{l_prefix}/etc/consul-replicate/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/consul-replicate/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/consul-replicate/*'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} consul-replicate status 2>/dev/null`
    [ ".$consul_replicate_active" = .yes ] && %{l_rc} consul-replicate restart
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} consul-replicate stop 2>/dev/null
    rm -rf $RPM_INSTALL_PREFIX/var/consul-replicate/log/*  >/dev/null 2>&1 || true
    rm -rf $RPM_INSTALL_PREFIX/var/consul-replicate/run/*  >/dev/null 2>&1 || true
    exit 0

